projectal.entities.access_policy API documentation

# projectal.entities.access_policy

View Source

    from projectal.entity import Entity
    from projectal.linkers import PermissionLinker, UserLinker

    class AccessPolicy(Entity, PermissionLinker, UserLinker):
        """
        Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
        """
        _path = 'access-policy'
        _name = 'access_policy'

        _links = [PermissionLinker]
        _links_reverse = [UserLinker]

class AccessPolicy(projectal.entity.Entity, projectal.linkers.PermissionLinker, projectal.linkers.UserLinker):
View Source

    class AccessPolicy(Entity, PermissionLinker, UserLinker):
        """
        Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
        """
        _path = 'access-policy'
        _name = 'access_policy'

        _links = [PermissionLinker]
        _links_reverse = [UserLinker]

Implementation of the Access Policy API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  entity_name
projectal.linkers.PermissionLinker
  link_permission
  unlink_permission
projectal.linkers.UserLinker
  link_user
  unlink_user
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy